@@ -89,11 +89,13 @@ sub body {
                       $children[0]->name =~ /{.*}(.+)/;    # process name
                     @children = @{$children[0]->contents}
                       if (@children == 1 && $local eq 'div');
-                    $content->{__body} = '<div>';
+
+                    # $content->{__body} = '<div>';
                     my $w = XML::Atom::Syndication::Writer->new;
                     $w->set_prefix('', 'http://www.w3.org/1999/xhtml');
                     map { $content->{__body} .= $w->as_xml($_) } @children;
-                    $content->{__body} .= '</div>';
+
+                    # $content->{__body} .= '</div>';
                 } else {
                     $content->{__body} = $elem->text_content;
                 }
@@ -133,7 +135,7 @@ Language-Sensitive.
 =head1 METHODS
 
 XML::Atom::Syndication::Content is a subclass of
-L<XML::Atom::Syndication:::Object> that it inherits numerous
+L<XML::Atom::Syndication::Object> that it inherits numerous
 methods from. You should already be familiar with this base
 class before proceeding.
 
